@@ -2,7 +2,6 @@
 
   example: src/pack_log.py --prd_type=sort --time_range=100  --timestamp="2022-09-13 17:55:00" --log_root_dir=/tmp/66log
 """
-from nis import cat
 from src.log_utility import *
 import argparse
 import tarfile
@@ -37,9 +36,18 @@ def init_input_args(sub_parser):
     sub_parser.add_argument(
         "--output_file", help=f"输出文件的路径, 默认路径：{OUTPUT_FILE}", default=OUTPUT_FILE
     )
-    sub_parser.add_argument(
-        "--recursive", action="store_true", help="是否递归查找子目录, 默认为True", default=True
-    )
+
+    # DON'T want to allow --feature and --no-feature at the same time
+    feature_recursive_parser = sub_parser.add_mutually_exclusive_group(required=False)
+    feature_recursive_parser.add_argument('--recursive', dest='recursive', action='store_true', help='递归处理log文件目录的子目录, 默认激活该选项')
+    feature_recursive_parser.add_argument('--no-recursive', dest='recursive', action='store_false', help='不处理log文件目录的子目录')
+    sub_parser.set_defaults(recursive=True)
+
+    feature_compress_parser = sub_parser.add_mutually_exclusive_group(required=False)
+    feature_compress_parser.add_argument('--compress', dest='compress', action='store_true', help="压缩输出文件, 默认激活该选项")
+    feature_compress_parser.add_argument('--no-compress', dest='compress', action='store_false', help="不压缩输出文件")
+    sub_parser.set_defaults(compress=True)
+
     return sub_parser
 
 
@@ -63,6 +71,7 @@ def pack_log(input_args):
     except (FileNotFoundError, IsADirectoryError):
         pass
 
+    print(f"input_args.recursive: {input_args.recursive}")
     log_files = set(
         get_file_in_time_range(
             input_args, download_log=True, recursive=input_args.recursive
@@ -76,17 +85,30 @@ def pack_log(input_args):
 
     print(f"totlal {len(log_files)} files, compress start ...")
 
-    # terminal process bar for compress with alive-progress with IO info
-    with alive_bar(len(log_files)) as bar:
-        with tarfile.open(input_args.output_file, "w:gz") as tar:
-            for log_file in log_files:
-                try:
-                    tar.add(log_file)
-                except FileNotFoundError:
-                    print(f"file {log_file} is not exist")
-            bar()
+    # if input_args.compress, tar with gzip
+    if input_args.compress:
+        with alive_bar(len(log_files),  title='pack with compress') as bar:
+            with tarfile.open(input_args.output_file, "w:gz") as tar:
+                for log_file in log_files:
+                    try:
+                        tar.add(log_file)
+                        bar()
+                    except FileNotFoundError:
+                        print(f"file {log_file} is not exist")
 
-    print(f"compress complete, total {len(log_files)} files, output file: {input_args.output_file}")
+    # else, tar without gzip
+    else:
+        with alive_bar(len(log_files),  title='pack without compress') as bar:
+            with tarfile.open(input_args.output_file, "w") as tar:
+                for log_file in log_files:
+                    try:
+                        tar.add(log_file)
+                        bar()
+                    except FileNotFoundError:
+                        print(f"file {log_file} is not exist")
+
+    # terminal process bar for compress with alive-progress
+    print(f"pack complete, total {len(log_files)} files, output file: {input_args.output_file}")
 
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(
